View Source K8s.Client.Mint.ConnectionRegistry (k8s v2.0.0-rc.2)
Opens Mint.HTTP2 connections and registers them in the GenServer state.
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor.
Ensures there is an adapter associated with the given key.
Starts the registry.
Link to this section Types
Link to this section Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Ensures there is an adapter associated with the given key.
@spec start_link(any()) :: GenServer.on_start()
Starts the registry.